@@ -56,7 +56,7 @@ static Atom windowOwnerMark;
 
 #define WINDOW (parentDetails.window)
 
-int error_handler(Display *dpy, XErrorEvent *err)
+static int error_handler(Display *dpy, XErrorEvent *err)
 {
 #ifdef DEBUG
      char buffer[1024];
@@ -70,7 +70,7 @@ int error_handler(Display *dpy, XErrorEvent *err)
 /*****************************************************************************
  * Swallow mutex semaphore protection
  *****************************************************************************/
-static void initSwallowMutex()
+static void initSwallowMutex(void)
 {
     D("Initialising Swallow Mutex\n"); 
     if(!display) 
@@ -85,7 +85,7 @@ static void initSwallowMutex()
     windowOwnerMark = XInternAtom(display, "MOZPLUGGER_OWNER", 0);
 }
 
-uint32 getHostId()
+static uint32 getHostId(void)
 {
     char hostName[128];
     uint32 id;
@@ -156,7 +156,7 @@ static void setSwallowMutexOwner(uint32 hostId, uint32 pid)
                         (unsigned char*) (&temp), 2);
 }
 
-static void takeSwallowMutex()
+static void takeSwallowMutex(void)
 {
     int countDown;
     uint32 ourPid = (uint32)getpid();
@@ -438,7 +438,7 @@ static void adjust_window_size(void)
  * Window reparenting
  *****************************************************************************/
 
-static void change_leader()
+static void change_leader(void)
 {
      XWMHints *leader_change;
      if ((leader_change = XGetWMHints(display, victimDetails.window)))
@@ -659,13 +659,13 @@ static Window find_winrecur(Window from, int depth, char *name)
      return (Window)0;
 }
 
-void save_initial_windows()
+static void save_initial_windows(void)
 {
      ignore_window_count = 0;
      init_winrecur(wattr.root, 3, winname);
 }
 
-static int setup_display()
+static int setup_display(void)
 {
      char *displayname = getenv("DISPLAY");
      D("setup_display(%s)\n", displayname);
@@ -968,7 +968,7 @@ static void check_pipe_fd_events(void)
      adjust_window_size();
 }
 
-static void check_all_events()
+static void check_all_events(void)
 {
      struct timeval tv;
      int maxfd;
@@ -1041,6 +1041,16 @@ static void handle_app(pid_t pid)
      D("Exited OK!\n");
 }
 
+/******************************************************************************
+ *
+ *****************************************************************************/
+static void exitEarly(void)
+{
+     fprintf(stderr,"MozPlugger version " VERSION " helper application.\n"
+		  "Please see 'man mozplugger' for details.\n");
+     exit(1);
+}
+
 /******************************************************************************
  * main() normally called from the child process started by mozplugger.so 
  * 
@@ -1048,20 +1058,18 @@ static void handle_app(pid_t pid)
 int main(int argc, char **argv)
 {
      unsigned long temp = 0;
-     int x, y;
+     int x, y, i;
      D("Helper started.....\n");
 
-     if (argc < 2)
+     if (argc < 3)
      {
-	  fprintf(stderr,"MozPlugger version " VERSION " helper application.\n"
-		  "Please see 'man mozplugger' for details.\n");
-	  exit(1);
+          exitEarly();
      }
 
      memset(&victimDetails, 0, sizeof(victimDetails));
      memset(&parentDetails, 0, sizeof(parentDetails));
 
-     sscanf(argv[1],"%d,%d,%d,%lu,%d,%d,%d,%d",
+     i = sscanf(argv[1],"%d,%d,%d,%lu,%d,%d,%d,%d",
 	    &flags,
 	    &repeats,
 	    &pipe_fd,
@@ -1071,6 +1079,11 @@ int main(int argc, char **argv)
 	    &parentDetails.width,
 	    &parentDetails.height);
 
+     if(i < 8)
+     {
+          exitEarly();
+     }
+
      parentDetails.window = (Window)temp;
 
      command = argv[2];
@@ -1087,7 +1100,7 @@ int main(int argc, char **argv)
 
      while (repeats > 0)
      {
-	  char *argv[10];
+	  char *app_argv[10];
 	  int loops = 1;
 	  pid_t pid;
 
@@ -1100,10 +1113,10 @@ int main(int argc, char **argv)
 	       loops = MAXINT;
 
 	  /* Create command line */
-	  argv[0] = "/bin/sh";
-	  argv[1] = "-c";
-	  argv[2] = command;
-	  argv[3] = NULL;
+	  app_argv[0] = "/bin/sh";
+	  app_argv[1] = "-c";
+	  app_argv[2] = command;
+	  app_argv[3] = NULL;
 	  
 	  if (setup_display())
 	  {
@@ -1146,7 +1159,7 @@ int main(int argc, char **argv)
                XSelectInput(display, wattr.root, 0);
 #endif
 	       D("Running %s\n", command);
-	       run_app(argv);
+	       run_app(app_argv);
 	  }
 	  else
 	  {
