@@ -86,9 +86,9 @@ typedef struct
 /*****************************************************************************
  * Global variables
  *****************************************************************************/
-static char *config_fname;
-static char *helper_fname;
-static char *controller_fname;
+static const char *config_fname;
+static const char *helper_fname;
+static const char *controller_fname;
 static int num_handlers;
 static handler_t handlers[MAX_NUM_HANDLERS];
 static int browserApiMajorVer;
@@ -313,7 +313,7 @@ static int inpath(char *path, const char *file)
      {
 	  snprintf(buf, sizeof(buf), "%s/%s", path, file);
 	  D("stat(%s)\n", buf);
-	  if (!stat(buf, &filestat))
+	  if (stat(buf, &filestat) == 0)
 	  {
 	       D("yes\n");
 	       return 1;
@@ -359,7 +359,7 @@ static int find(const char *file)
 
      if (file[0] == '/')
      {
-	  exists = !stat(file, &filestat);
+	  exists = (stat(file, &filestat) == 0);
      }
      else
      {
@@ -675,9 +675,7 @@ static void read_config(FILE *f)
 /*****************************************************************************
  * Find the config file or the helper file in function of the function cb.
  *****************************************************************************/
-static int find_helper_file(const char *basename, 
-                            int (*cb)(const char *,void *data), 
-                            void *data)
+static int find_helper_file(const char *basename, int (*cb)(const char *))
 {
      static char fname[LARGE_BUFFER_SIZE];
      char *tmp;
@@ -687,45 +685,49 @@ static int find_helper_file(const char *basename,
      if ((tmp = getenv("HOME")))
      {
 	  snprintf(fname, sizeof(fname), "%s/.netscape/%s", tmp, basename);
-	  if (cb(fname,data)) return 1;
+	  if (cb(fname)) return 1;
 
 	  snprintf(fname, sizeof(fname), "%s/.mozilla/%s", tmp, basename);
-	  if (cb(fname,data)) return 1;
+	  if (cb(fname)) return 1;
 
 	  snprintf(fname, sizeof(fname), "%s/.opera/%s", tmp, basename);
-	  if (cb(fname,data)) return 1;
+	  if (cb(fname)) return 1;
      }
 
      if ((tmp = getenv("MOZILLA_HOME")))
      {
 	  snprintf(fname, sizeof(fname), "%s/%s", tmp, basename);
-	  if (cb(fname, data)) return 1;
+	  if (cb(fname)) return 1;
      }
 
      if ((tmp = getenv("OPERA_DIR")))
      {
 	  snprintf(fname, sizeof(fname), "%s/%s", tmp, basename);
-	  if (cb(fname, data)) return 1;
+	  if (cb(fname)) return 1;
      }
 
      snprintf(fname, sizeof(fname), "/etc/%s", basename);
-     if (cb(fname, data)) return 1;
+     if (cb(fname)) return 1;
 
      snprintf(fname, sizeof(fname), "/usr/etc/%s", basename);
-     if (cb(fname, data)) return 1;
+     if (cb(fname)) return 1;
 
      snprintf(fname, sizeof(fname), "/usr/local/mozilla/%s", basename);
-     if (cb(fname, data)) return 1;
+     if (cb(fname)) return 1;
 
      snprintf(fname, sizeof(fname), "/usr/local/netscape/%s", basename);
-     if (cb(fname, data)) return 1;
+     if (cb(fname)) return 1;
 
-     if (cb(basename, data)) return 1;
+     if (cb(basename)) return 1;
   
      return 0;
 }
 
-static int read_config_cb(const char *fname, void *data)
+/*****************************************************************************
+ * Open and run the configuration file (fname) through M4 and then call 
+ * read_config() to parse the output
+ ****************************************************************************/
+static int read_config_cb(const char *fname)
 {
      int m4out[2];
      pid_t pid;
@@ -771,29 +773,46 @@ static int read_config_cb(const char *fname, void *data)
 	  fclose(fp);
 	  
 	  waitpid(pid, 0, 0);
-	  config_fname = strdup(fname);
+	  config_fname = makeStrStatic(fname, strlen(fname));
+
      }
      return 1;
 }
 
-static int find_plugger_helper_cb(const char *fname, void *data)
+/*****************************************************************************
+ * Check if the helper executable exists (using stat), if so save the filename
+ * to the global 'helper_fname' variable
+ *****************************************************************************/
+static int find_plugger_helper_cb(const char *fname)
 {
      struct stat buf;
-     if (stat(fname, &buf)) return 0;
-     helper_fname = strdup(fname);
-     return 1;
-}
-
-static int find_plugger_controller_cb(const char *fname, void *data)
-{
-     struct stat buf;
-     if (stat(fname, &buf)) return 0;
-     controller_fname = strdup(fname);
+     if (stat(fname, &buf) != 0) 
+     {
+          return 0;
+     }
+     helper_fname = makeStrStatic(fname, strlen(fname));
      return 1;
 }
 
 /*****************************************************************************
- * Find configuration file and read it into memory.
+ * Check if the controller executable exists (using stat), if so save the
+ * filename to the global 'controller_fname' variable
+ *****************************************************************************/
+static int find_plugger_controller_cb(const char *fname)
+{
+     struct stat buf;
+     if (stat(fname, &buf) != 0) 
+     {
+          return 0;
+     }
+     controller_fname = makeStrStatic(fname, strlen(fname));
+     return 1;
+}
+
+/*****************************************************************************
+ * Find configuration file, helper and controller executables. Call the
+ * appropriate xxx_cb function to handle the action (e.g. for configuration
+ * file, the parsering and reading into memory).
  *****************************************************************************/
 static void do_read_config(void)
 {
@@ -801,27 +820,33 @@ static void do_read_config(void)
 
      D("do_read_config\n");
   
-     if (!find_helper_file("mozpluggerrc", read_config_cb, 0))
+     if (!find_helper_file("mozpluggerrc", read_config_cb))
      {
 	  fprintf(stderr, "MozPlugger: Warning: Unable to find the mozpluggerrc file.\n");
 	  return;
      }
 
-     if (!find_helper_file("mozplugger-helper", find_plugger_helper_cb, 0))
+     if (!find_helper_file("mozplugger-helper", find_plugger_helper_cb))
      {
-	  if (find("mozplugger-helper")) {
+	  if (find("mozplugger-helper")) 
+          {
 	       helper_fname = "mozplugger-helper";
-	  } else { 
+	  } 
+          else 
+          { 
 	       fprintf(stderr, "MozPlugger: Warning: Unable to find mozplugger-helper.\n");
 	       return;
 	  }
      }
 
-     if (!find_helper_file("mozplugger-controller", find_plugger_controller_cb, 0))
+     if (!find_helper_file("mozplugger-controller", find_plugger_controller_cb))
      {
-	  if (find("mozplugger-controller")) {
+	  if (find("mozplugger-controller")) 
+          {
 	       controller_fname = "mozplugger-controller";
-	  } else {
+	  } 
+          else 
+          {
 	       fprintf(stderr, "MozPlugger: Warning: Unable to find mozplugger-controller.\n");
 	       return;
 	  }
@@ -1567,7 +1592,7 @@ void NPP_StreamAsFile(NPP instance,
  * ns4xPluginInstance.cpp (13 Nov 2003), at the time version was 0.13.
  * version 0.14 happened on 14th July 2004
  ****************************************************************************/
-void resize_window(NPP instance)
+static void resize_window(NPP instance)
 {
      XSetWindowAttributes attrib;
 
@@ -1651,7 +1676,9 @@ NPError NPP_SetWindow(NPP instance, NPWindow* window)
 }
 
 /*****************************************************************************
- * Empty functions.
+ * Called from the Browser when the streaming has been completed by the Browser
+ * (the reason code indicates whether this was due to a User action, Network
+ * issue or that streaming has been done.
  *****************************************************************************/
 NPError NPP_DestroyStream(NPP instance, NPStream *stream, NPError reason)
 {
@@ -1688,22 +1715,43 @@ NPError NPP_Initialize(void)
      return NPERR_NO_ERROR;
 }
 
+/*****************************************************************************
+ * The browser calls this function once; when the plug-in is loaded. It returns
+ * the Java Class associated with this plug-in. In this case there is None.
+ *****************************************************************************/
 jref NPP_GetJavaClass()
 {
      D("GetJavaClass\n");
      return NULL;
 }
 
+/*****************************************************************************
+ * The browser calls this function just before it unloads the plugin from
+ * memory. So this function should do any tidy up - in this case nothing is
+ * required.
+ *****************************************************************************/
 void NPP_Shutdown(void)
 {
      D("Shutdown\n");
 }
 
+/*****************************************************************************
+ * Called when user as requested to print the webpage that contains a visible
+ * plug-in. For mozplugger this is ignored.
+ *****************************************************************************/
 void NPP_Print(NPP instance, NPPrint* printInfo)
 {
      D("Print() - instance=%p\n", instance);
 }
 
+/*****************************************************************************
+ * Called when the Browser wishes to deliver a block of data from a stream to
+ * the plugin. Since streaming is handled directly by the application specificed
+ * in the configuration file, mozplugger has no need for this data. Here it
+ * just pretends the data has been taken by returning 'len' to indicate all 
+ * bytes consumed. Actaully this function should never be called by the 
+ * Browser.
+ *****************************************************************************/
 int32 NPP_Write(NPP instance,
 		NPStream *stream,
 		int32 offset,
@@ -1714,6 +1762,13 @@ int32 NPP_Write(NPP instance,
      return len;
 }
 
+/*****************************************************************************
+ * Browser calls this function before calling NPP_Write to see how much data
+ * the plugin is ready to accept. Since streaming is handled directly by the
+ * application specified in the configuration file, mozplugger does not need
+ * the stream data from the Browser, therefore this fucntion terminates
+ * the streaming by calling NPN_DestoryStream.
+ *****************************************************************************/
 int32 NPP_WriteReady(NPP instance, NPStream *stream)
 {
     D("WriteReady() - instance=%p\n", instance);
