@@ -38,14 +38,7 @@
 #define MAX_NUM_TYPES_PER_HANDLER 32
 #define MAX_NUM_CMDS_PER_HANDLER 32
 
-/* Maximum size of a mime type line. */
-#define MAX_TYPE_SIZE 256
-
-/* Maximum size of a command line. */
-#define MAX_CMD_SIZE 512
-
-/* Maximum size of a swallow() window. */
-#define MAX_WINNAME_SIZE 128
+#define MAX_STATIC_MEMORY_POOL   65536
 
 /* Maximum size of the buffer used for environment variables. */
 #define ENV_BUFFER_SIZE 16348
@@ -55,6 +48,7 @@
 
 #define SMALL_BUFFER_SIZE 128
 #define SMALL_BUFFER_SIZE_STR "128"
+#define FIND_CACHE_SIZE   10
 
 /* Flags */
 #define H_LOOP 		0x1
@@ -71,6 +65,7 @@
 #define H_HIDDEN        0x800
 #define H_CONTROLS 	0x1000
 #define H_LINKS         0x2000
+#define H_FMATCH        0x4000
 
 /*****************************************************************************
  * mozplugger-common.c functions
